@@ -21,7 +21,7 @@ class SSSDOptions(object):
         'debug_level': _('Set the verbosity of the debug logging'),
         'debug_timestamps': _('Include timestamps in debug logs'),
         'debug_microseconds': _('Include microseconds in timestamps in debug logs'),
-        'debug_to_files': _('Write debug messages to logfiles'),
+        'debug_backtrace_enabled': _('Enable/disable debug backtrace'),
         'timeout': _('Watchdog timeout before restarting service'),
         'command': _('Command to start service'),
         'reconnection_retries': _('Number of times to attempt connection to Data Providers'),
@@ -38,7 +38,6 @@ class SSSDOptions(object):
             'Indicates what is the syntax of the config file. SSSD 0.6.0 and later use version 2.'),
         'services': _('SSSD Services to start'),
         'domains': _('SSSD Domains to start'),
-        'sbus_timeout': _('Timeout for messages sent over the SBUS'),
         're_expression': _('Regex to parse username and domain'),
         'full_name_format': _('Printf-compatible format for displaying fully-qualified names'),
         'krb5_rcache_dir': _('Directory on the filesystem where SSSD should store Kerberos replay cache files.'),
@@ -72,9 +71,12 @@ class SSSDOptions(object):
         'shell_fallback': _('If a shell stored in central directory is allowed but not available, use this fallback'),
         'default_shell': _('Shell to use if the provider does not list one'),
         'memcache_timeout': _('How long will be in-memory cache records valid'),
-        'memcache_size_passwd': _('Size (in megabytes) of the data table allocated inside fast in-memory cache for passwd requests'),
-        'memcache_size_group': _('Size (in megabytes) of the data table allocated inside fast in-memory cache for group requests'),
-        'memcache_size_initgroups': _('Size (in megabytes) of the data table allocated inside fast in-memory cache for initgroups requests'),
+        'memcache_size_passwd': _(
+            'Size (in megabytes) of the data table allocated inside fast in-memory cache for passwd requests'),
+        'memcache_size_group': _(
+            'Size (in megabytes) of the data table allocated inside fast in-memory cache for group requests'),
+        'memcache_size_initgroups': _(
+            'Size (in megabytes) of the data table allocated inside fast in-memory cache for initgroups requests'),
         'homedir_substring': _('The value of this option will be used in the expansion of the override_homedir option '
                                'if the template contains the format string %H.'),
         'get_domains_timeout': _('Specifies time in seconds for which the list of subdomains will be considered '
@@ -98,16 +100,17 @@ class SSSDOptions(object):
         'pam_account_locked_message': _('Message printed when user account is locked.'),
         'pam_cert_auth': _('Allow certificate based/Smartcard authentication.'),
         'pam_cert_db_path': _('Path to certificate database with PKCS#11 modules.'),
+        'pam_cert_verification': _('Tune certificate verification for PAM authentication.'),
         'p11_child_timeout': _('How many seconds will pam_sss wait for p11_child to finish'),
         'pam_app_services': _('Which PAM services are permitted to contact application domains'),
         'pam_p11_allowed_services': _('Allowed services for using smartcards'),
         'p11_wait_for_card_timeout': _('Additional timeout to wait for a card if requested'),
         'p11_uri': _('PKCS#11 URI to restrict the selection of devices for Smartcard authentication'),
-        'pam_initgroups_scheme' : _('When shall the PAM responder force an initgroups request'),
-        'pam_gssapi_services' : _('List of PAM services that are allowed to authenticate with GSSAPI.'),
-        'pam_gssapi_check_upn' : _('Whether to match authenticated UPN with target user'),
-        'pam_gssapi_indicators_map' : _('List of pairs <PAM service>:<authentication indicator> that '
-                                        'must be enforced for PAM access with GSSAPI authentication'),
+        'pam_initgroups_scheme': _('When shall the PAM responder force an initgroups request'),
+        'pam_gssapi_services': _('List of PAM services that are allowed to authenticate with GSSAPI.'),
+        'pam_gssapi_check_upn': _('Whether to match authenticated UPN with target user'),
+        'pam_gssapi_indicators_map': _('List of pairs <PAM service>:<authentication indicator> that '
+                                       'must be enforced for PAM access with GSSAPI authentication'),
 
         # [sudo]
         'sudo_timed': _('Whether to evaluate the time-based attributes in sudo rules'),
@@ -134,29 +137,6 @@ class SSSDOptions(object):
         # [ifp]
         'user_attributes': _('List of user attributes the InfoPipe is allowed to publish'),
 
-        # [secrets]
-        'provider': _('The provider where the secrets will be stored in'),
-        'containers_nest_level': _('The maximum allowed number of nested containers'),
-        'max_secrets': _('The maximum number of secrets that can be stored'),
-        'max_uid_secrets': _('The maximum number of secrets that can be stored per UID'),
-        'max_payload_size': _('The maximum payload size of a secret in kilobytes'),
-        # secrets - proxy
-        'proxy_url': _('The URL Custodia server is listening on'),
-        'auth_type': _('The method to use when authenticating to a Custodia server'),
-        'auth_header_name': _('The name of the headers that will be added into a HTTP request with the value defined '
-                              'in auth_header_value'),
-        'auth_header_value': _('The value sssd-secrets would use for auth_header_name'),
-        'forward_headers': _('The list of the headers to forward to the Custodia server together with the request'),
-        'username': _('The username to use when authenticating to a Custodia server using basic_auth'),
-        'password': _('The password to use when authenticating to a Custodia server using basic_auth'),
-        'verify_peer': _('If true peer\'s certificate is verified if proxy_url uses https protocol'),
-        'verify_host': _('If false peer\'s certificate may contain different hostname than proxy_url when https '
-                         'protocol is used'),
-        'capath': _('Path to directory where certificate authority certificates are stored'),
-        'cacert': _('Path to file containing server\'s CA certificate'),
-        'cert': _('Path to file containing client\'s certificate'),
-        'key': _('Path to file containing client\'s private key'),
-
         # [session_recording]
         'scope': _('One of the following strings specifying the scope of session recording: none - No users are '
                    'recorded. some - Users/groups specified by users and groups options are recorded. all - All users '
@@ -180,7 +160,7 @@ class SSSDOptions(object):
         'hostid_provider': _('Host identity provider'),
         'selinux_provider': _('SELinux provider'),
         'session_provider': _('Session management provider'),
-        'resolver_provider' : _('Resolver provider'),
+        'resolver_provider': _('Resolver provider'),
 
         # [domain]
         'domain_type': _('Whether the domain is usable by the OS or by applications'),
@@ -207,7 +187,7 @@ class SSSDOptions(object):
         'entry_cache_service_timeout': _('Entry cache timeout length (seconds)'),
         'entry_cache_autofs_timeout': _('Entry cache timeout length (seconds)'),
         'entry_cache_sudo_timeout': _('Entry cache timeout length (seconds)'),
-        'entry_cache_resolver_timeout' : _('Entry cache timeout length (seconds)'),
+        'entry_cache_resolver_timeout': _('Entry cache timeout length (seconds)'),
         'refresh_expired_interval': _('How often should expired entries be refreshed in background'),
         'dyndns_update': _("Whether to automatically update the client's DNS entry"),
         'dyndns_ttl': _("The TTL to apply to the client's DNS entry after updating it"),
@@ -264,6 +244,7 @@ class SSSDOptions(object):
         'ipa_deskprofile_request_interval': _("The amount of time in minutes between lookups of Desktop Profiles "
                                               "rules against the IPA server when the last request did not find any "
                                               "rule"),
+        'ipa_subid_ranges_search_base': _("Search base for SUBID ranges"),
         'ipa_host_fqdn': _('The LDAP attribute that contains FQDN of the host.'),
         'ipa_host_object_class': _('The object class of a host entry in LDAP.'),
         'ipa_host_search_base': _('Use the given string as search base for host objects.'),
@@ -326,7 +307,7 @@ class SSSDOptions(object):
         'ad_update_samba_machine_account_password': _('Whether to update the machine account password in the Samba '
                                                       'database'),
         'ad_use_ldaps': _('Use LDAPS port for LDAP and Global Catalog requests'),
-        'ad_allow_remote_domain_local_groups' : _('Do not filter domain local groups from other domains'),
+        'ad_allow_remote_domain_local_groups': _('Do not filter domain local groups from other domains'),
 
         # [provider/krb5]
         'krb5_kdcip': _('Kerberos server address'),
@@ -348,6 +329,7 @@ class SSSDOptions(object):
         'krb5_renew_interval': _("Time between two checks for renewal"),
         'krb5_use_fast': _("Enables FAST"),
         'krb5_fast_principal': _("Selects the principal to use for FAST"),
+        'krb5_fast_use_anonymous_pkinit': _("Use anonymous PKINIT to request FAST credentials"),
         'krb5_canonicalize': _("Enables principal canonicalization"),
         'krb5_use_enterprise_principal': _("Enables enterprise principals"),
         'krb5_use_subdomain_realm': _("Enables using of subdomains realms for authentication"),
@@ -389,6 +371,7 @@ class SSSDOptions(object):
         'ldap_dns_service_name': _('Service name for DNS service lookups'),
         'ldap_page_size': _('The number of records to retrieve in a single LDAP query'),
         'ldap_deref_threshold': _('The number of members that must be missing to trigger a full deref'),
+        'ldap_ignore_unreadable_references': _('Ignore unreadable LDAP references'),
         'ldap_sasl_canonicalize': _('Whether the LDAP library should perform a reverse lookup to canonicalize the '
                                     'host name during a SASL bind'),
         'ldap_rfc2307_fallback_to_local_users': _('Allows to retain local users as members of an LDAP group for '
@@ -514,6 +497,7 @@ class SSSDOptions(object):
         'ldap_sudo_search_base': _('Base DN for sudo rules lookups'),
         'ldap_sudo_full_refresh_interval': _('Automatic full refresh period'),
         'ldap_sudo_smart_refresh_interval': _('Automatic smart refresh period'),
+        'ldap_sudo_random_offset': _('Smart and full refresh random offset'),
         'ldap_sudo_use_host_filter': _('Whether to filter rules by hostname, IP addresses and network'),
         'ldap_sudo_hostnames': _('Hostnames and/or fully qualified domain names of this machine to filter sudo rules'),
         'ldap_sudo_ip': _('IPv4 or IPv6 addresses or network of this machine to filter sudo rules'),
@@ -562,21 +546,12 @@ class SSSDOptions(object):
         'simple_deny_groups': _('Comma separated list of groups that are explicitly denied access. This applies only '
                                 'to groups within this SSSD domain. Local groups are not evaluated.'),
 
-        # [provider/local/id]
-        'base_directory': _('Base for home directories'),
-        'create_homedir': _('Indicate if a home directory should be created for new users.'),
-        'remove_homedir': _('Indicate if a home directory should be removed for deleted users.'),
-        'homedir_umask': _('Specify the default permissions on a newly created home directory.'),
-        'skel_dir': _('The skeleton directory.'),
-        'mail_dir': _('The mail spool directory.'),
-        'userdel_cmd': _('The command that is run after a user is removed.'),
-
         # [provider/proxy]
         'proxy_max_children': _('The number of preforked proxy children.'),
 
         # [provider/proxy/id]
         'proxy_lib_name': _('The name of the NSS library to use'),
-        'proxy_resolver_lib_name' : _('The name of the NSS library to use for hosts and networks lookups'),
+        'proxy_resolver_lib_name': _('The name of the NSS library to use for hosts and networks lookups'),
         'proxy_fast_alias': _('Whether to look up canonical group name from cache if possible'),
 
         # [provider/proxy/auth]
